@@ -4,8 +4,10 @@ function(seedGene,
   coeffMissingAllowed = 0.75,
   subsetToUse = 1:ncol(geData),
   cpuCluster = NULL, stopCpuCluster = TRUE) {
+     
+  if(areDataNotLoaded()) return(NULL)
   
-   if(areDataNotLoaded()) return(NULL)
+  zero = NULL
   
   if(is.null(cpuCluster)) {
     ans <- sequentialSignatureFinder(seedGene, subsetToUse = subsetToUse,
@@ -17,10 +19,12 @@ function(seedGene,
   # export the funtions to the clusetr of cpu's
   clusterEvalQ(cpuCluster,  library(geneSignatureFinder))
   #instantiate the parallel version of the searching algorithm.
-    ans <- parallelSignatureFinder(cpuCluster, seedGene,
+  ans <- parallelSignatureFinder(cpuCluster, seedGene,
       logFileName = logFilePrefix, coeffMissingAllowed = coeffMissingAllowed,
-      subsetToUse = subsetToUse)
+      subsetToUse = subsetToUse, zero = zero)
     if(stopCpuCluster) stopCluster(cpuCluster)
   }
+   
+  class(ans) <- "gSignature"
   return(ans)
 }
