@@ -1,6 +1,5 @@
 tValueFun <-
-function(ndx, coeffMissingAllowed = 0.75)
-  {
+function(ndx, coeffMissingAllowed = 0.75) {
     notMissing <- apply(!is.na(geData[, ndx]), 1, sum)
     notMissing <- notMissing > floor((length(ndx)-1)^coeffMissingAllowed)
     clusters <- classify(geData[notMissing, ndx])$clusters
